<a id="types-aiobotocore-greengrass"></a>

# types-aiobotocore-greengrass

[![PyPI - types-aiobotocore-greengrass](https://img.shields.io/pypi/v/types-aiobotocore-greengrass.svg?color=blue)](https://pypi.org/project/types-aiobotocore-greengrass)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-greengrass.svg?color=blue)](https://pypi.org/project/types-aiobotocore-greengrass)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-greengrass?color=blue)](https://pypistats.org/packages/types-aiobotocore-greengrass)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.Greengrass 2.3.4](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/greengrass.html#Greengrass)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.11.3](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-greengrass docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_greengrass/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-greengrass](#types-aiobotocore-greengrass)
  - [How to install](#how-to-install)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `Greengrass` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[greengrass]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[greengrass]'


# standalone installation
python -m pip install types-aiobotocore-greengrass
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-greengrass
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[greengrass]` in your environment:

```bash
python -m pip install 'types-aiobotocore[greengrass]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[greengrass]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[greengrass]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[greengrass]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[greengrass]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[greengrass]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[greengrass]` in your environment:

```bash
python -m pip install 'types-aiobotocore[greengrass]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[greengrass]` in your environment:

```bash
python -m pip install 'types-aiobotocore[greengrass]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`GreengrassClient` provides annotations for
`session.create_client("greengrass")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_greengrass import GreengrassClient

session = get_session()
async with session.create_client("greengrass") as client:
    client: GreengrassClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_greengrass.paginator` module contains type annotations for
all paginators.

```python
from aiobotocore.session import get_session

from types_aiobotocore_greengrass import GreengrassClient
from types_aiobotocore_greengrass.paginator import (
    ListBulkDeploymentDetailedReportsPaginator,
    ListBulkDeploymentsPaginator,
    ListConnectorDefinitionVersionsPaginator,
    ListConnectorDefinitionsPaginator,
    ListCoreDefinitionVersionsPaginator,
    ListCoreDefinitionsPaginator,
    ListDeploymentsPaginator,
    ListDeviceDefinitionVersionsPaginator,
    ListDeviceDefinitionsPaginator,
    ListFunctionDefinitionVersionsPaginator,
    ListFunctionDefinitionsPaginator,
    ListGroupVersionsPaginator,
    ListGroupsPaginator,
    ListLoggerDefinitionVersionsPaginator,
    ListLoggerDefinitionsPaginator,
    ListResourceDefinitionVersionsPaginator,
    ListResourceDefinitionsPaginator,
    ListSubscriptionDefinitionVersionsPaginator,
    ListSubscriptionDefinitionsPaginator,
)

session = get_session()
async with session.create_client("greengrass") as client:
    client: GreengrassClient

    # Explicit type annotations are optional here
    # Types should be correctly discovered by mypy and IDEs
    list_bulk_deployment_detailed_reports_paginator: ListBulkDeploymentDetailedReportsPaginator = (
        client.get_paginator("list_bulk_deployment_detailed_reports")
    )
    list_bulk_deployments_paginator: ListBulkDeploymentsPaginator = client.get_paginator(
        "list_bulk_deployments"
    )
    list_connector_definition_versions_paginator: ListConnectorDefinitionVersionsPaginator = (
        client.get_paginator("list_connector_definition_versions")
    )
    list_connector_definitions_paginator: ListConnectorDefinitionsPaginator = client.get_paginator(
        "list_connector_definitions"
    )
    list_core_definition_versions_paginator: ListCoreDefinitionVersionsPaginator = (
        client.get_paginator("list_core_definition_versions")
    )
    list_core_definitions_paginator: ListCoreDefinitionsPaginator = client.get_paginator(
        "list_core_definitions"
    )
    list_deployments_paginator: ListDeploymentsPaginator = client.get_paginator("list_deployments")
    list_device_definition_versions_paginator: ListDeviceDefinitionVersionsPaginator = (
        client.get_paginator("list_device_definition_versions")
    )
    list_device_definitions_paginator: ListDeviceDefinitionsPaginator = client.get_paginator(
        "list_device_definitions"
    )
    list_function_definition_versions_paginator: ListFunctionDefinitionVersionsPaginator = (
        client.get_paginator("list_function_definition_versions")
    )
    list_function_definitions_paginator: ListFunctionDefinitionsPaginator = client.get_paginator(
        "list_function_definitions"
    )
    list_group_versions_paginator: ListGroupVersionsPaginator = client.get_paginator(
        "list_group_versions"
    )
    list_groups_paginator: ListGroupsPaginator = client.get_paginator("list_groups")
    list_logger_definition_versions_paginator: ListLoggerDefinitionVersionsPaginator = (
        client.get_paginator("list_logger_definition_versions")
    )
    list_logger_definitions_paginator: ListLoggerDefinitionsPaginator = client.get_paginator(
        "list_logger_definitions"
    )
    list_resource_definition_versions_paginator: ListResourceDefinitionVersionsPaginator = (
        client.get_paginator("list_resource_definition_versions")
    )
    list_resource_definitions_paginator: ListResourceDefinitionsPaginator = client.get_paginator(
        "list_resource_definitions"
    )
    list_subscription_definition_versions_paginator: ListSubscriptionDefinitionVersionsPaginator = (
        client.get_paginator("list_subscription_definition_versions")
    )
    list_subscription_definitions_paginator: ListSubscriptionDefinitionsPaginator = (
        client.get_paginator("list_subscription_definitions")
    )
```

<a id="literals"></a>

### Literals

`types_aiobotocore_greengrass.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from types_aiobotocore_greengrass.literals import (
    BulkDeploymentStatusType,
    ConfigurationSyncStatusType,
    DeploymentTypeType,
    EncodingTypeType,
    FunctionIsolationModeType,
    ListBulkDeploymentDetailedReportsPaginatorName,
    ListBulkDeploymentsPaginatorName,
    ListConnectorDefinitionVersionsPaginatorName,
    ListConnectorDefinitionsPaginatorName,
    ListCoreDefinitionVersionsPaginatorName,
    ListCoreDefinitionsPaginatorName,
    ListDeploymentsPaginatorName,
    ListDeviceDefinitionVersionsPaginatorName,
    ListDeviceDefinitionsPaginatorName,
    ListFunctionDefinitionVersionsPaginatorName,
    ListFunctionDefinitionsPaginatorName,
    ListGroupVersionsPaginatorName,
    ListGroupsPaginatorName,
    ListLoggerDefinitionVersionsPaginatorName,
    ListLoggerDefinitionsPaginatorName,
    ListResourceDefinitionVersionsPaginatorName,
    ListResourceDefinitionsPaginatorName,
    ListSubscriptionDefinitionVersionsPaginatorName,
    ListSubscriptionDefinitionsPaginatorName,
    LoggerComponentType,
    LoggerLevelType,
    LoggerTypeType,
    PermissionType,
    SoftwareToUpdateType,
    TelemetryType,
    UpdateAgentLogLevelType,
    UpdateTargetsArchitectureType,
    UpdateTargetsOperatingSystemType,
    GreengrassServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)


def check_value(value: BulkDeploymentStatusType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_greengrass.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_greengrass.type_defs import (
    AssociateRoleToGroupRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    AssociateServiceRoleToAccountRequestRequestTypeDef,
    BulkDeploymentMetricsTypeDef,
    ErrorDetailTypeDef,
    BulkDeploymentTypeDef,
    ConnectivityInfoTypeDef,
    ConnectorTypeDef,
    CoreTypeDef,
    CreateDeploymentRequestRequestTypeDef,
    DeviceTypeDef,
    CreateGroupCertificateAuthorityRequestRequestTypeDef,
    GroupVersionTypeDef,
    CreateGroupVersionRequestRequestTypeDef,
    LoggerTypeDef,
    CreateSoftwareUpdateJobRequestRequestTypeDef,
    SubscriptionTypeDef,
    DefinitionInformationTypeDef,
    DeleteConnectorDefinitionRequestRequestTypeDef,
    DeleteCoreDefinitionRequestRequestTypeDef,
    DeleteDeviceDefinitionRequestRequestTypeDef,
    DeleteFunctionDefinitionRequestRequestTypeDef,
    DeleteGroupRequestRequestTypeDef,
    DeleteLoggerDefinitionRequestRequestTypeDef,
    DeleteResourceDefinitionRequestRequestTypeDef,
    DeleteSubscriptionDefinitionRequestRequestTypeDef,
    DeploymentTypeDef,
    DisassociateRoleFromGroupRequestRequestTypeDef,
    ResourceAccessPolicyTypeDef,
    FunctionRunAsConfigTypeDef,
    GetAssociatedRoleRequestRequestTypeDef,
    GetBulkDeploymentStatusRequestRequestTypeDef,
    GetConnectivityInfoRequestRequestTypeDef,
    GetConnectorDefinitionRequestRequestTypeDef,
    GetConnectorDefinitionVersionRequestRequestTypeDef,
    GetCoreDefinitionRequestRequestTypeDef,
    GetCoreDefinitionVersionRequestRequestTypeDef,
    GetDeploymentStatusRequestRequestTypeDef,
    GetDeviceDefinitionRequestRequestTypeDef,
    GetDeviceDefinitionVersionRequestRequestTypeDef,
    GetFunctionDefinitionRequestRequestTypeDef,
    GetFunctionDefinitionVersionRequestRequestTypeDef,
    GetGroupCertificateAuthorityRequestRequestTypeDef,
    GetGroupCertificateConfigurationRequestRequestTypeDef,
    GetGroupRequestRequestTypeDef,
    GetGroupVersionRequestRequestTypeDef,
    GetLoggerDefinitionRequestRequestTypeDef,
    GetLoggerDefinitionVersionRequestRequestTypeDef,
    GetResourceDefinitionRequestRequestTypeDef,
    GetResourceDefinitionVersionRequestRequestTypeDef,
    GetSubscriptionDefinitionRequestRequestTypeDef,
    GetSubscriptionDefinitionVersionRequestRequestTypeDef,
    GetThingRuntimeConfigurationRequestRequestTypeDef,
    GroupCertificateAuthorityPropertiesTypeDef,
    GroupInformationTypeDef,
    GroupOwnerSettingTypeDef,
    PaginatorConfigTypeDef,
    ListBulkDeploymentDetailedReportsRequestRequestTypeDef,
    ListBulkDeploymentsRequestRequestTypeDef,
    ListConnectorDefinitionVersionsRequestRequestTypeDef,
    VersionInformationTypeDef,
    ListConnectorDefinitionsRequestRequestTypeDef,
    ListCoreDefinitionVersionsRequestRequestTypeDef,
    ListCoreDefinitionsRequestRequestTypeDef,
    ListDeploymentsRequestRequestTypeDef,
    ListDeviceDefinitionVersionsRequestRequestTypeDef,
    ListDeviceDefinitionsRequestRequestTypeDef,
    ListFunctionDefinitionVersionsRequestRequestTypeDef,
    ListFunctionDefinitionsRequestRequestTypeDef,
    ListGroupCertificateAuthoritiesRequestRequestTypeDef,
    ListGroupVersionsRequestRequestTypeDef,
    ListGroupsRequestRequestTypeDef,
    ListLoggerDefinitionVersionsRequestRequestTypeDef,
    ListLoggerDefinitionsRequestRequestTypeDef,
    ListResourceDefinitionVersionsRequestRequestTypeDef,
    ListResourceDefinitionsRequestRequestTypeDef,
    ListSubscriptionDefinitionVersionsRequestRequestTypeDef,
    ListSubscriptionDefinitionsRequestRequestTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ResetDeploymentsRequestRequestTypeDef,
    SecretsManagerSecretResourceDataTypeDef,
    ResourceDownloadOwnerSettingTypeDef,
    TelemetryConfigurationTypeDef,
    StartBulkDeploymentRequestRequestTypeDef,
    StopBulkDeploymentRequestRequestTypeDef,
    TagResourceRequestRequestTypeDef,
    TelemetryConfigurationUpdateTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateConnectorDefinitionRequestRequestTypeDef,
    UpdateCoreDefinitionRequestRequestTypeDef,
    UpdateDeviceDefinitionRequestRequestTypeDef,
    UpdateFunctionDefinitionRequestRequestTypeDef,
    UpdateGroupCertificateConfigurationRequestRequestTypeDef,
    UpdateGroupRequestRequestTypeDef,
    UpdateLoggerDefinitionRequestRequestTypeDef,
    UpdateResourceDefinitionRequestRequestTypeDef,
    UpdateSubscriptionDefinitionRequestRequestTypeDef,
    AssociateRoleToGroupResponseTypeDef,
    AssociateServiceRoleToAccountResponseTypeDef,
    CreateConnectorDefinitionResponseTypeDef,
    CreateConnectorDefinitionVersionResponseTypeDef,
    CreateCoreDefinitionResponseTypeDef,
    CreateCoreDefinitionVersionResponseTypeDef,
    CreateDeploymentResponseTypeDef,
    CreateDeviceDefinitionResponseTypeDef,
    CreateDeviceDefinitionVersionResponseTypeDef,
    CreateFunctionDefinitionResponseTypeDef,
    CreateFunctionDefinitionVersionResponseTypeDef,
    CreateGroupCertificateAuthorityResponseTypeDef,
    CreateGroupResponseTypeDef,
    CreateGroupVersionResponseTypeDef,
    CreateLoggerDefinitionResponseTypeDef,
    CreateLoggerDefinitionVersionResponseTypeDef,
    CreateResourceDefinitionResponseTypeDef,
    CreateResourceDefinitionVersionResponseTypeDef,
    CreateSoftwareUpdateJobResponseTypeDef,
    CreateSubscriptionDefinitionResponseTypeDef,
    CreateSubscriptionDefinitionVersionResponseTypeDef,
    DisassociateRoleFromGroupResponseTypeDef,
    DisassociateServiceRoleFromAccountResponseTypeDef,
    EmptyResponseMetadataTypeDef,
    GetAssociatedRoleResponseTypeDef,
    GetConnectorDefinitionResponseTypeDef,
    GetCoreDefinitionResponseTypeDef,
    GetDeviceDefinitionResponseTypeDef,
    GetFunctionDefinitionResponseTypeDef,
    GetGroupCertificateAuthorityResponseTypeDef,
    GetGroupCertificateConfigurationResponseTypeDef,
    GetGroupResponseTypeDef,
    GetLoggerDefinitionResponseTypeDef,
    GetResourceDefinitionResponseTypeDef,
    GetServiceRoleForAccountResponseTypeDef,
    GetSubscriptionDefinitionResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ResetDeploymentsResponseTypeDef,
    StartBulkDeploymentResponseTypeDef,
    UpdateConnectivityInfoResponseTypeDef,
    UpdateGroupCertificateConfigurationResponseTypeDef,
    BulkDeploymentResultTypeDef,
    GetBulkDeploymentStatusResponseTypeDef,
    GetDeploymentStatusResponseTypeDef,
    ListBulkDeploymentsResponseTypeDef,
    GetConnectivityInfoResponseTypeDef,
    UpdateConnectivityInfoRequestRequestTypeDef,
    ConnectorDefinitionVersionTypeDef,
    CreateConnectorDefinitionVersionRequestRequestTypeDef,
    CoreDefinitionVersionTypeDef,
    CreateCoreDefinitionVersionRequestRequestTypeDef,
    CreateDeviceDefinitionVersionRequestRequestTypeDef,
    DeviceDefinitionVersionTypeDef,
    CreateGroupRequestRequestTypeDef,
    GetGroupVersionResponseTypeDef,
    CreateLoggerDefinitionVersionRequestRequestTypeDef,
    LoggerDefinitionVersionTypeDef,
    CreateSubscriptionDefinitionVersionRequestRequestTypeDef,
    SubscriptionDefinitionVersionTypeDef,
    ListConnectorDefinitionsResponseTypeDef,
    ListCoreDefinitionsResponseTypeDef,
    ListDeviceDefinitionsResponseTypeDef,
    ListFunctionDefinitionsResponseTypeDef,
    ListLoggerDefinitionsResponseTypeDef,
    ListResourceDefinitionsResponseTypeDef,
    ListSubscriptionDefinitionsResponseTypeDef,
    ListDeploymentsResponseTypeDef,
    FunctionDefaultExecutionConfigTypeDef,
    FunctionExecutionConfigTypeDef,
    ListGroupCertificateAuthoritiesResponseTypeDef,
    ListGroupsResponseTypeDef,
    LocalDeviceResourceDataTypeDef,
    LocalVolumeResourceDataTypeDef,
    ListBulkDeploymentDetailedReportsRequestListBulkDeploymentDetailedReportsPaginateTypeDef,
    ListBulkDeploymentsRequestListBulkDeploymentsPaginateTypeDef,
    ListConnectorDefinitionVersionsRequestListConnectorDefinitionVersionsPaginateTypeDef,
    ListConnectorDefinitionsRequestListConnectorDefinitionsPaginateTypeDef,
    ListCoreDefinitionVersionsRequestListCoreDefinitionVersionsPaginateTypeDef,
    ListCoreDefinitionsRequestListCoreDefinitionsPaginateTypeDef,
    ListDeploymentsRequestListDeploymentsPaginateTypeDef,
    ListDeviceDefinitionVersionsRequestListDeviceDefinitionVersionsPaginateTypeDef,
    ListDeviceDefinitionsRequestListDeviceDefinitionsPaginateTypeDef,
    ListFunctionDefinitionVersionsRequestListFunctionDefinitionVersionsPaginateTypeDef,
    ListFunctionDefinitionsRequestListFunctionDefinitionsPaginateTypeDef,
    ListGroupVersionsRequestListGroupVersionsPaginateTypeDef,
    ListGroupsRequestListGroupsPaginateTypeDef,
    ListLoggerDefinitionVersionsRequestListLoggerDefinitionVersionsPaginateTypeDef,
    ListLoggerDefinitionsRequestListLoggerDefinitionsPaginateTypeDef,
    ListResourceDefinitionVersionsRequestListResourceDefinitionVersionsPaginateTypeDef,
    ListResourceDefinitionsRequestListResourceDefinitionsPaginateTypeDef,
    ListSubscriptionDefinitionVersionsRequestListSubscriptionDefinitionVersionsPaginateTypeDef,
    ListSubscriptionDefinitionsRequestListSubscriptionDefinitionsPaginateTypeDef,
    ListConnectorDefinitionVersionsResponseTypeDef,
    ListCoreDefinitionVersionsResponseTypeDef,
    ListDeviceDefinitionVersionsResponseTypeDef,
    ListFunctionDefinitionVersionsResponseTypeDef,
    ListGroupVersionsResponseTypeDef,
    ListLoggerDefinitionVersionsResponseTypeDef,
    ListResourceDefinitionVersionsResponseTypeDef,
    ListSubscriptionDefinitionVersionsResponseTypeDef,
    S3MachineLearningModelResourceDataTypeDef,
    SageMakerMachineLearningModelResourceDataTypeDef,
    RuntimeConfigurationTypeDef,
    UpdateThingRuntimeConfigurationRequestRequestTypeDef,
    ListBulkDeploymentDetailedReportsResponseTypeDef,
    CreateConnectorDefinitionRequestRequestTypeDef,
    GetConnectorDefinitionVersionResponseTypeDef,
    CreateCoreDefinitionRequestRequestTypeDef,
    GetCoreDefinitionVersionResponseTypeDef,
    CreateDeviceDefinitionRequestRequestTypeDef,
    GetDeviceDefinitionVersionResponseTypeDef,
    CreateLoggerDefinitionRequestRequestTypeDef,
    GetLoggerDefinitionVersionResponseTypeDef,
    CreateSubscriptionDefinitionRequestRequestTypeDef,
    GetSubscriptionDefinitionVersionResponseTypeDef,
    FunctionDefaultConfigTypeDef,
    FunctionConfigurationEnvironmentTypeDef,
    ResourceDataContainerTypeDef,
    GetThingRuntimeConfigurationResponseTypeDef,
    FunctionConfigurationTypeDef,
    ResourceTypeDef,
    FunctionTypeDef,
    CreateResourceDefinitionVersionRequestRequestTypeDef,
    ResourceDefinitionVersionTypeDef,
    CreateFunctionDefinitionVersionRequestRequestTypeDef,
    FunctionDefinitionVersionTypeDef,
    CreateResourceDefinitionRequestRequestTypeDef,
    GetResourceDefinitionVersionResponseTypeDef,
    CreateFunctionDefinitionRequestRequestTypeDef,
    GetFunctionDefinitionVersionResponseTypeDef,
)


def get_structure() -> AssociateRoleToGroupRequestRequestTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-greengrass` version is the same as related `aiobotocore`
version and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/)
format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_greengrass/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
